Struct plaid::deposit_switch::GetDepositSwitchResponse[][src]

pub struct GetDepositSwitchResponse {
    pub request_id: String,
    pub deposit_switch: String,
    pub target_account_id: Option<String>,
    pub target_item_id: Option<String>,
    pub state: String,
    pub account_has_multiple_allocations: Option<bool>,
    pub is_allocated_remainder: Option<bool>,
    pub percent_allocated: Option<i32>,
    pub amount_allocated: Option<f64>,
    pub date_created: NaiveDate,
    pub date_completed: Option<NaiveDate>,
}

Fields

request_id: String

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.

deposit_switch: String

The ID of the deposit switch

target_account_id: Option<String>

The ID of the bank account the direct deposit was switched to

target_item_id: Option<String>

The ID of the Item the direct deposit was switched to.

state: String

The state of the deposit switch. Possible values: initialized, completed, error

account_has_multiple_allocations: Option<bool>

When true, user’s direct deposit goes to multiple banks. When false, user’s direct deposit only goes to the target account. Always null if the deposit switch has not been completed.

is_allocated_remainder: Option<bool>

When true, the target account is allocated the remainder of direct deposit after all other allocations have been deducted. When false, user’s direct deposit is allocated as a percent or amount. Always null if the deposit switch has not been completed.

percent_allocated: Option<i32>

The percentage of direct deposit allocated to the target account. Always null if the target account is not allocated a percentage or if the deposit switch has not been completed or if is_allocated_remainder is true.

amount_allocated: Option<f64>

The dollar amount of direct deposit allocated to the target account. Always null if the target account is not allocated an amount or if the deposit switch has not been completed.

date_created: NaiveDate

ISO8601 date the deposit switch was created.

date_completed: Option<NaiveDate>

ISO8601 date the deposit switch was completed. Always null if the deposit switch has not been completed.