Struct plaid::deposit_switch::GetDepositSwitchResponse [−][src]
Fields
request_id: StringA unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.
deposit_switch: StringThe ID of the deposit switch
target_account_id: Option<String>The ID of the bank account the direct deposit was switched to
target_item_id: Option<String>The ID of the Item the direct deposit was switched to.
state: StringThe state of the deposit switch. Possible values: initialized, completed, error
account_has_multiple_allocations: Option<bool>When true, user’s direct deposit goes to multiple banks. When false, user’s direct deposit only goes to the target account. Always null if the deposit switch has not been completed.
is_allocated_remainder: Option<bool>When true, the target account is allocated the remainder of direct deposit after all other allocations have been deducted. When false, user’s direct deposit is allocated as a percent or amount. Always null if the deposit switch has not been completed.
percent_allocated: Option<i32>The percentage of direct deposit allocated to the target account. Always null if the target account is not allocated a percentage or if the deposit switch has not been completed or if is_allocated_remainder is true.
amount_allocated: Option<f64>The dollar amount of direct deposit allocated to the target account. Always null if the target account is not allocated an amount or if the deposit switch has not been completed.
date_created: NaiveDateISO8601 date the deposit switch was created.
date_completed: Option<NaiveDate>ISO8601 date the deposit switch was completed. Always null if the deposit switch has not been completed.